@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "dialog_import_csv_progress.h"
@@ -79,7 +79,7 @@ void Dialog_Import_CSV_Progress::import(Dialog_Import_CSV& data_source)
     }
     catch(const Glib::ConvertError& ex)
     {
-      std::cerr << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
+      std::cerr << G_STRFUNC << ": Glib::filename_from_uri() failed: " << ex.what() << std::endl;
     }
 
     m_progress_bar->set_text(Glib::ustring::compose(_("Parsing CSV file %1"), filename));
